from hdsr_wis_config_reader.constants.idmappings import collection
from hdsr_wis_config_reader.constants.idmappings import columns
from hdsr_wis_config_reader.constants.idmappings import custom_dataframe
from hdsr_wis_config_reader.constants.idmappings import files
from hdsr_wis_config_reader.constants.idmappings import sections
from hdsr_wis_config_reader.constants.idmappings.collection import IdMappingCollection


# silence flake8 errors
collection = collection
columns = columns
custom_dataframe = custom_dataframe
files = files
sections = sections
IdMappingCollection = IdMappingCollection
